<?php

global $authenticate_text;
$authenticate_text = array (

'loginsuccessful'	=>	'Login corretto.',
'loginfailed'		=>	'Login FALLITO!',
'userandpass'		=>	'Non hai inserito sia username che password.',
'youareloggedout'	=>	'Sei stato disconnesso.',
'waitwhiletransfer'	=>	'Aspetta mentre vieni trasferito...',
'clicknowait'		=>	'Clicca qui se non vuoi aspettare.',
                            
// Added in 0.9.7
'accountdisabled'       =>      'Il tuo account e\' disabilitato, Contatta un full admin.',

);
?>
